@@ -1,18 +1,21 @@
-import json
 import sys
 import signal
 import time
 from decimal import Decimal
+from typing import Optional, Tuple
 
 from django.core.management import BaseCommand, CommandError
 from stellar_sdk import Keypair
+from stellar_sdk.account import Account
+from stellar_sdk.exceptions import BaseHorizonError
+from stellar_sdk.transaction_builder import TransactionBuilder
 
 from polaris import settings
 from polaris.utils import (
     create_stellar_deposit,
     create_transaction_envelope,
-    get_or_create_transaction_destination_account,
     get_account_obj,
+    is_pending_trust,
 )
 from polaris.integrations import (
     registered_deposit_integration as rdi,
@@ -44,9 +47,9 @@ def execute_deposit(transaction: Transaction) -> bool:
         transaction.status = Transaction.STATUS.pending_anchor
     transaction.status_eta = 5  # Ledger close time.
     transaction.save()
-    logger.info(f"Transaction {transaction.id} now pending_anchor, initiating deposit")
+    logger.info(f"Initiating Stellar deposit for {transaction.id}")
     # launch the deposit Stellar transaction.
-    return create_stellar_deposit(transaction, destination_exists=True)
+    return create_stellar_deposit(transaction)
 
 
 def check_for_multisig(transaction):
@@ -54,7 +57,7 @@ def check_for_multisig(transaction):
     if transaction.asset.distribution_account_master_signer:
         master_signer = transaction.asset.distribution_account_master_signer
     thresholds = transaction.asset.distribution_account_thresholds
-    if not (master_signer and master_signer["weight"] >= thresholds["med_threshold"]):
+    if not master_signer or master_signer["weight"] < thresholds["med_threshold"]:
         # master account is not sufficient
         transaction.pending_signatures = True
         transaction.status = Transaction.STATUS.pending_anchor
@@ -83,6 +86,82 @@ def check_for_multisig(transaction):
         return False
 
 
+def get_or_create_transaction_destination_account(
+    transaction: Transaction,
+) -> Tuple[Optional[Account], bool, bool]:
+    """
+    Returns:
+        Tuple[Optional[Account]: The account(s) found or created for the Transaction
+        bool: boolean, True if created, False otherwise.
+        bool: boolean, True if trustline doesn't exist, False otherwise.
+
+    If the account doesn't exist, Polaris must create the account using an account provided by the
+    anchor. Polaris can use the distribution account of the anchored asset or a channel account if
+    the asset's distribution account requires non-master signatures.
+
+    If the transacted asset's distribution account does not require non-master signatures, Polaris
+    can create the destination account using the distribution account.
+
+    If the transacted asset's distribution account does require non-master signatures, the anchor
+    should save a keypair of a pre-existing Stellar account to use as the channel account via
+    DepositIntegration.create_channel_account(). See the function docstring for more info.
+
+    On failure to create the destination account, a RuntimeError exception is raised.
+    """
+    try:
+        account, json_resp = get_account_obj(
+            Keypair.from_public_key(transaction.stellar_account)
+        )
+        return account, False, is_pending_trust(transaction, json_resp)
+    except RuntimeError:
+        master_signer = None
+        if transaction.asset.distribution_account_master_signer:
+            master_signer = transaction.asset.distribution_account_master_signer
+        thresholds = transaction.asset.distribution_account_thresholds
+        if master_signer and master_signer["weight"] >= thresholds["med_threshold"]:
+            source_account_kp = Keypair.from_secret(transaction.asset.distribution_seed)
+            source_account, _ = get_account_obj(source_account_kp)
+        else:
+            from polaris.integrations import registered_deposit_integration as rdi
+
+            rdi.create_channel_account(transaction)
+            source_account_kp = Keypair.from_secret(transaction.channel_seed)
+            source_account, _ = get_account_obj(source_account_kp)
+
+        builder = TransactionBuilder(
+            source_account=source_account,
+            network_passphrase=settings.STELLAR_NETWORK_PASSPHRASE,
+            # this transaction contains one operation so base_fee will be multiplied by 1
+            base_fee=settings.MAX_TRANSACTION_FEE_STROOPS
+            or settings.HORIZON_SERVER.fetch_base_fee(),
+        )
+        transaction_envelope = builder.append_create_account_op(
+            destination=transaction.stellar_account,
+            starting_balance=settings.ACCOUNT_STARTING_BALANCE,
+        ).build()
+        transaction_envelope.sign(source_account_kp)
+
+        try:
+            settings.HORIZON_SERVER.submit_transaction(transaction_envelope)
+        except BaseHorizonError as submit_exc:  # pragma: no cover
+            raise RuntimeError(
+                "Horizon error when submitting create account to horizon: "
+                f"{submit_exc.message}"
+            )
+
+        transaction.status = Transaction.STATUS.pending_trust
+        transaction.save()
+        logger.info(
+            f"Transaction {transaction.id} is now pending_trust of destination account"
+        )
+        account, _ = get_account_obj(
+            Keypair.from_public_key(transaction.stellar_account)
+        )
+        return account, True, True
+    except BaseHorizonError as e:
+        raise RuntimeError(f"Horizon error when loading stellar account: {e.message}")
+
+
 class Command(BaseCommand):
     """
     Polls the anchor's financial entity, gathers ready deposit transactions
@@ -123,7 +202,7 @@ class Command(BaseCommand):
             "Defaults to {}.".format(DEFAULT_INTERVAL),
         )
 
-    def handle(self, *args, **options):  # pragma: no cover
+    def handle(self, *_args, **options):  # pragma: no cover
         module = sys.modules[__name__]
         if options.get("loop"):
             while True:
@@ -136,14 +215,12 @@ class Command(BaseCommand):
 
     @classmethod
     def execute_deposits(cls):
-        """
-        Right now, execute_deposits assumes all pending deposits are SEP-6 or 24
-        transactions. This may change in the future if Polaris adds support for
-        another SEP that checks for incoming deposits.
-        """
         module = sys.modules[__name__]
         pending_deposits = Transaction.objects.filter(
-            status=Transaction.STATUS.pending_user_transfer_start,
+            status__in=[
+                Transaction.STATUS.pending_user_transfer_start,
+                Transaction.STATUS.pending_external,
+            ],
             kind=Transaction.KIND.deposit,
         )
         try:
@@ -179,7 +256,6 @@ class Command(BaseCommand):
                     )
                 else:
                     transaction.amount_fee = Decimal(0)
-            logger.info("calling get_or_create_transaction_destination_account()")
             try:
                 (
                     _,
@@ -193,24 +269,17 @@ class Command(BaseCommand):
                 logger.error(transaction.status_message)
                 continue
 
-            # Transaction.status == pending_trust, wait for client
-            # to add trustline for asset to send
-            if created or pending_trust:
+            if (
+                created or pending_trust
+            ) and not transaction.claimable_balance_supported:
                 logger.info(
                     f"destination account is pending_trust for transaction {transaction.id}"
                 )
-                if (
-                    pending_trust
-                    and transaction.status != Transaction.STATUS.pending_trust
-                ):
-                    transaction.status = Transaction.STATUS.pending_trust
-                    transaction.save()
+                transaction.status = Transaction.STATUS.pending_trust
+                transaction.save()
                 continue
-
-            if check_for_multisig(transaction):
-                # Now Polaris waits for signatures to be collected by the anchor
+            elif check_for_multisig(transaction):
                 continue
-
             cls.execute_deposit(transaction)
 
         ready_multisig_transactions = Transaction.objects.filter(
