@@ -7,6 +7,7 @@ from urllib.parse import urlencode
 from polaris.utils import getLogger
 
 from django.urls import reverse
+from django.core.exceptions import ValidationError
 from django.shortcuts import redirect
 from django.views.decorators.clickjacking import xframe_options_exempt
 from django.utils.translation import gettext as _
@@ -180,7 +181,7 @@ def post_interactive_deposit(request: Request) -> Response:
 
 
 @api_view(["GET"])
-@renderer_classes([])
+@renderer_classes([TemplateHTMLRenderer])
 @check_authentication()
 def complete_interactive_deposit(request: Request) -> Response:
     """
@@ -196,9 +197,14 @@ def complete_interactive_deposit(request: Request) -> Response:
         return render_error_response(
             _("Missing id parameter in URL"), content_type="text/html"
         )
-    Transaction.objects.filter(id=transaction_id).update(
-        status=Transaction.STATUS.pending_user_transfer_start
-    )
+    try:
+        Transaction.objects.filter(id=transaction_id).update(
+            status=Transaction.STATUS.pending_user_transfer_start
+        )
+    except ValidationError:
+        return render_error_response(
+            _("ID passed is not a valid transaction ID"), content_type="text/html"
+        )
     logger.info(f"Hands-off interactive flow complete for transaction {transaction_id}")
     url, args = (
         reverse("more_info"),
